@@ -76,23 +76,6 @@ ALWAYS_INLINE char* SuperPagesEndFromExtent(
          (extent->number_of_consecutive_super_pages * kSuperPageSize);
 }
 
-// SlotSpanMetadata::Free() defers unmapping a large page until the lock is
-// released. Callers of SlotSpanMetadata::Free() must invoke Run().
-// TODO(1061437): Reconsider once the new locking mechanism is implemented.
-struct DeferredUnmap {
-  void* reservation_start = nullptr;
-  size_t reservation_size = 0;
-  pool_handle giga_cage_pool;
-
-  // In most cases there is no page to unmap and reservation_start == nullptr.
-  // This function is inlined to avoid the overhead of a function call in the
-  // common case.
-  ALWAYS_INLINE void Run();
-
- private:
-  BASE_EXPORT NOINLINE void Unmap();
-};
-
 using QuarantineBitmap =
     ObjectBitmap<kSuperPageSize, kSuperPageAlignment, kAlignment>;
 
@@ -145,9 +128,8 @@ struct __attribute__((packed)) SlotSpanMetadata {
 
   // Public API
   // Note the matching Alloc() functions are in PartitionPage.
-  // Callers must invoke DeferredUnmap::Run() after releasing the lock.
-  BASE_EXPORT NOINLINE DeferredUnmap FreeSlowPath() WARN_UNUSED_RESULT;
-  ALWAYS_INLINE DeferredUnmap Free(void* ptr) WARN_UNUSED_RESULT;
+  BASE_EXPORT NOINLINE void FreeSlowPath();
+  ALWAYS_INLINE void Free(void* ptr);
 
   void Decommit(PartitionRoot<thread_safe>* root);
   void DecommitIfPossible(PartitionRoot<thread_safe>* root);
@@ -187,6 +169,15 @@ struct __attribute__((packed)) SlotSpanMetadata {
     return GetRawSize();
   }
 
+  // This includes padding due to rounding done at allocation; we don't know the
+  // requested size at deallocation, so we use this in both places.
+  ALWAYS_INLINE size_t GetSizeForBookkeeping() const {
+    // This could be more precise for allocations where CanStoreRawSize()
+    // returns true (large allocations). However this is called for *every*
+    // allocation, so we don't want an extra branch there.
+    return bucket->slot_size;
+  }
+
   // Returns the size available to the app. It can be equal or higher than the
   // requested size. If higher, the overage won't exceed what's actually usable
   // by the app without a risk of running out of an allocated region or into
@@ -446,8 +437,14 @@ ALWAYS_INLINE char* GetSlotStartInSuperPage(char* maybe_inner_ptr) {
   PA_DCHECK(IsWithinSuperPagePayload(maybe_inner_ptr,
                                      extent->root->IsQuarantineAllowed()));
 #endif
-  auto* slot_span =
-      SlotSpanMetadata<thread_safe>::FromSlotInnerPtr(maybe_inner_ptr);
+  // Don't use FromSlotInnerPtr() because |is_valid| DCHECKs can fail there.
+  auto* page = PartitionPage<thread_safe>::FromPtr(maybe_inner_ptr);
+  if (!page->is_valid)
+    return nullptr;
+  page -= page->slot_span_metadata_offset;
+  PA_DCHECK(page->is_valid);
+  PA_DCHECK(!page->slot_span_metadata_offset);
+  auto* slot_span = &page->slot_span_metadata;
   // Check if the slot span is actually used and valid.
   if (!slot_span->bucket)
     return nullptr;
@@ -630,8 +627,9 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::SetFreelistHead(
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE DeferredUnmap
-SlotSpanMetadata<thread_safe>::Free(void* slot_start) {
+ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Free(void* slot_start)
+    EXCLUSIVE_LOCKS_REQUIRED(
+        PartitionRoot<thread_safe>::FromSlotSpan(this)->lock_) {
 #if DCHECK_IS_ON()
   auto* root = PartitionRoot<thread_safe>::FromSlotSpan(this);
   root->lock_.AssertAcquired();
@@ -648,13 +646,12 @@ SlotSpanMetadata<thread_safe>::Free(void* slot_start) {
   SetFreelistHead(entry);
   --num_allocated_slots;
   if (UNLIKELY(num_allocated_slots <= 0)) {
-    return FreeSlowPath();
+    FreeSlowPath();
   } else {
     // All single-slot allocations must go through the slow path to
     // correctly update the raw size.
     PA_DCHECK(!CanStoreRawSize());
   }
-  return {};
 }
 
 template <bool thread_safe>
@@ -704,12 +701,6 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Reset() {
   next_slot_span = nullptr;
 }
 
-ALWAYS_INLINE void DeferredUnmap::Run() {
-  if (UNLIKELY(reservation_start)) {
-    Unmap();
-  }
-}
-
 enum class QuarantineBitmapType { kMutator, kScanner };
 
 // Returns a quarantine bitmap from a pointer within a normal-bucket super page.
