@@ -221,14 +221,21 @@ struct BASE_EXPORT PartitionRoot {
   // - total_size_of_committed_pages - total committed pages for slots (doesn't
   //     include metadata, bitmaps (if any), or any data outside or regions
   //     described in #1 and #2)
-  // Invariant: total_size_of_committed_pages <
+  // Invariant: total_size_of_allocated_bytes <=
+  //            total_size_of_committed_pages <
   //                total_size_of_super_pages +
   //                total_size_of_direct_mapped_pages.
-  // Since all operations on these atomic variables have relaxed semantics, we
-  // don't check this invariant with DCHECKs.
+  // Invariant: total_size_of_committed_pages <= max_size_of_committed_pages.
+  // Invariant: total_size_of_allocated_bytes <= max_size_of_allocated_bytes.
+  // Invariant: max_size_of_allocated_bytes <= max_size_of_committed_pages.
+  // Since all operations on the atomic variables have relaxed semantics, we
+  // don't check these invariants with DCHECKs.
   std::atomic<size_t> total_size_of_committed_pages{0};
+  std::atomic<size_t> max_size_of_committed_pages{0};
   std::atomic<size_t> total_size_of_super_pages{0};
   std::atomic<size_t> total_size_of_direct_mapped_pages{0};
+  size_t total_size_of_allocated_bytes GUARDED_BY(lock_) = 0;
+  size_t max_size_of_allocated_bytes GUARDED_BY(lock_) = 0;
 
   char* next_super_page = nullptr;
   char* next_partition_page = nullptr;
@@ -354,11 +361,17 @@ struct BASE_EXPORT PartitionRoot {
                  bool is_light_dump,
                  PartitionStatsDumper* partition_stats_dumper);
 
+  void ResetBookkeepingForTesting();
+
   static uint16_t SizeToBucketIndex(size_t size);
 
+  ALWAYS_INLINE void FreeSlotSpan(void* slot_start, SlotSpan* slot_span)
+      EXCLUSIVE_LOCKS_REQUIRED(lock_);
+
   // Frees memory, with |slot_start| as returned by |RawAlloc()|.
   ALWAYS_INLINE void RawFree(void* slot_start);
-  ALWAYS_INLINE void RawFree(void* slot_start, SlotSpan* slot_span);
+  ALWAYS_INLINE void RawFree(void* slot_start, SlotSpan* slot_span)
+      LOCKS_EXCLUDED(lock_);
 
   ALWAYS_INLINE void RawFreeWithThreadCache(void* slot_start,
                                             SlotSpan* slot_span);
@@ -369,6 +382,21 @@ struct BASE_EXPORT PartitionRoot {
   size_t get_total_size_of_committed_pages() const {
     return total_size_of_committed_pages.load(std::memory_order_relaxed);
   }
+  size_t get_max_size_of_committed_pages() const {
+    return max_size_of_committed_pages.load(std::memory_order_relaxed);
+  }
+
+  size_t get_total_size_of_allocated_bytes() const {
+    // Since this is only used for bookkeeping, we don't care if the value is
+    // stale, so no need to get a lock here.
+    return TS_UNCHECKED_READ(total_size_of_allocated_bytes);
+  }
+
+  size_t get_max_size_of_allocated_bytes() const {
+    // Since this is only used for bookkeeping, we don't care if the value is
+    // stale, so no need to get a lock here.
+    return TS_UNCHECKED_READ(max_size_of_allocated_bytes);
+  }
 
   internal::pool_handle ChooseGigaCagePool(bool is_direct_map) const {
 #if BUILDFLAG(USE_BACKUP_REF_PTR)
@@ -837,6 +865,9 @@ ALWAYS_INLINE void* PartitionRoot<thread_safe>::AllocFromBucket(
     *usable_size = slot_span->GetUsableSize(this);
   }
   PA_DCHECK(slot_span->GetUtilizedSlotSize() <= slot_span->bucket->slot_size);
+  total_size_of_allocated_bytes += slot_span->GetSizeForBookkeeping();
+  max_size_of_allocated_bytes =
+      std::max(max_size_of_allocated_bytes, total_size_of_allocated_bytes);
   return slot_start;
 }
 
@@ -1000,6 +1031,14 @@ ALWAYS_INLINE void PartitionRoot<thread_safe>::FreeNoHooksImmediate(
   RawFreeWithThreadCache(slot_start, slot_span);
 }
 
+template <bool thread_safe>
+ALWAYS_INLINE void PartitionRoot<thread_safe>::FreeSlotSpan(
+    void* slot_start,
+    SlotSpan* slot_span) {
+  total_size_of_allocated_bytes -= slot_span->GetSizeForBookkeeping();
+  return slot_span->Free(slot_start);
+}
+
 template <bool thread_safe>
 ALWAYS_INLINE void PartitionRoot<thread_safe>::RawFree(void* slot_start) {
   SlotSpan* slot_span = SlotSpan::FromSlotStartPtr(slot_start);
@@ -1041,12 +1080,8 @@ ALWAYS_INLINE void PartitionRoot<thread_safe>::RawFree(void* slot_start,
   // Do not move the store above inside the locked section.
   __asm__ __volatile__("" : : "r"(slot_start) : "memory");
 
-  internal::DeferredUnmap deferred_unmap;
-  {
-    ScopedGuard guard{lock_};
-    deferred_unmap = slot_span->Free(slot_start);
-  }
-  deferred_unmap.Run();
+  ScopedGuard guard{lock_};
+  FreeSlotSpan(slot_start, slot_span);
 }
 
 template <bool thread_safe>
@@ -1076,10 +1111,11 @@ ALWAYS_INLINE void PartitionRoot<thread_safe>::RawFreeWithThreadCache(
 template <bool thread_safe>
 ALWAYS_INLINE void PartitionRoot<thread_safe>::RawFreeLocked(void* slot_start) {
   SlotSpan* slot_span = SlotSpan::FromSlotStartPtr(slot_start);
-  auto deferred_unmap = slot_span->Free(slot_start);
-  // Only used with bucketed allocations.
-  PA_DCHECK(!deferred_unmap.reservation_start);
-  deferred_unmap.Run();
+  // Direct-mapped deallocation releases then re-acquires the lock. The caller
+  // may not expect that, but we never call this function on direct-mapped
+  // allocations.
+  PA_DCHECK(!IsDirectMappedBucket(slot_span->bucket));
+  FreeSlotSpan(slot_start, slot_span);
 }
 
 // static
@@ -1120,7 +1156,19 @@ PartitionRoot<thread_safe>::FromPointerInNormalBuckets(char* ptr) {
 template <bool thread_safe>
 ALWAYS_INLINE void PartitionRoot<thread_safe>::IncreaseCommittedPages(
     size_t len) {
-  total_size_of_committed_pages.fetch_add(len, std::memory_order_relaxed);
+  const auto old_total =
+      total_size_of_committed_pages.fetch_add(len, std::memory_order_relaxed);
+
+  const auto new_total = old_total + len;
+
+  // This function is called quite frequently; to avoid performance problems, we
+  // don't want to hold a lock here, so we use compare and exchange instead.
+  size_t expected = max_size_of_committed_pages.load(std::memory_order_relaxed);
+  size_t desired;
+  do {
+    desired = std::max(expected, new_total);
+  } while (!max_size_of_committed_pages.compare_exchange_weak(
+      expected, desired, std::memory_order_relaxed, std::memory_order_relaxed));
 }
 
 template <bool thread_safe>
@@ -1352,7 +1400,7 @@ ALWAYS_INLINE void* PartitionRoot<thread_safe>::AllocFlagsNoHooks(
   //   (e) utilized_slot_size
   //   (f) slot_size
   //
-  // - Ref-count may or may not exist in the slot, depending on CheckedPtr
+  // - Ref-count may or may not exist in the slot, depending on raw_ptr<T>
   //   implementation.
   // - Cookies exist only when DCHECK is on.
   // - Think of raw_size as the minimum size required internally to satisfy
