@@ -35,6 +35,7 @@ enum SdkVersion {
   SDK_VERSION_P = 28,
   SDK_VERSION_Q = 29,
   SDK_VERSION_R = 30,
+  SDK_VERSION_S = 31,
 };
 
 // BuildInfo is a singleton class that stores android build and device
@@ -42,7 +43,6 @@ enum SdkVersion {
 // primarily in crash reporting.
 class BASE_EXPORT BuildInfo {
  public:
-
   ~BuildInfo() {}
 
   // Static factory method for getting the singleton BuildInfo instance.
@@ -51,10 +51,6 @@ class BASE_EXPORT BuildInfo {
   // should only be one instance of BuildInfo ever created.
   static BuildInfo* GetInstance();
 
-  // Checks if the device is running on a pre-release version of Android S or a
-  // release version of Android S or newer.
-  bool IsAtLeastS();
-
   // Const char* is used instead of std::strings because these values must be
   // available even if the process is in a crash state. Sadly
   // std::string.c_str() doesn't guarantee that memory won't be allocated when
