@@ -6,6 +6,7 @@
 
 #include <vector>
 
+#include "base/feature_list.h"
 #include "build/build_config.h"
 
 namespace net {
@@ -148,12 +149,6 @@ const base::FeatureParam<std::string>
 const base::Feature kNetUnusedIdleSocketTimeout{
     "NetUnusedIdleSocketTimeout", base::FEATURE_DISABLED_BY_DEFAULT};
 
-const base::Feature kSameSiteByDefaultCookies{"SameSiteByDefaultCookies",
-                                              base::FEATURE_ENABLED_BY_DEFAULT};
-
-const base::Feature kCookiesWithoutSameSiteMustBeSecure{
-    "CookiesWithoutSameSiteMustBeSecure", base::FEATURE_ENABLED_BY_DEFAULT};
-
 const base::Feature kShortLaxAllowUnsafeThreshold{
     "ShortLaxAllowUnsafeThreshold", base::FEATURE_DISABLED_BY_DEFAULT};
 
@@ -184,6 +179,11 @@ const base::FeatureParam<int> kCertDualVerificationTrialCacheSize{
 #endif /* defined(OS_MAC) */
 #endif
 
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+const base::Feature kChromeRootStoreUsed{"ChromeRootStoreUsed",
+                                         base::FEATURE_DISABLED_BY_DEFAULT};
+#endif /* BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED) */
+
 const base::Feature kTurnOffStreamingMediaCachingOnBattery{
     "TurnOffStreamingMediaCachingOnBattery", base::FEATURE_DISABLED_BY_DEFAULT};
 
@@ -240,12 +240,6 @@ constexpr base::Feature kFirstPartySets{"FirstPartySets",
 const base::FeatureParam<bool> kFirstPartySetsIsDogfooder{
     &kFirstPartySets, "FirstPartySetsIsDogfooder", false};
 
-const base::Feature kSameSiteCookiesBugfix1166211{
-    "SameSiteCookiesBugfix1166211", base::FEATURE_ENABLED_BY_DEFAULT};
-
-const base::Feature kNoCookieChangeNotificationOnLoad{
-    "NoCookieChangeNotificationOnLoad", base::FEATURE_ENABLED_BY_DEFAULT};
-
 #if BUILDFLAG(ENABLE_REPORTING)
 const base::Feature kDocumentReporting{"DocumentReporting",
                                        base::FEATURE_DISABLED_BY_DEFAULT};
@@ -254,7 +248,7 @@ const base::Feature kDocumentReporting{"DocumentReporting",
 #if defined(OS_POSIX) || defined(OS_FUCHSIA)
 const base::Feature kUdpSocketPosixAlwaysUpdateBytesReceived{
     "UdpSocketPosixAlwaysUpdateBytesReceived",
-    base::FEATURE_DISABLED_BY_DEFAULT};
+    base::FEATURE_ENABLED_BY_DEFAULT};
 #endif  // defined(OS_POSIX) || defined(OS_FUCHSIA)
 
 const base::Feature kCookieSameSiteConsidersRedirectChain{
@@ -263,5 +257,8 @@ const base::Feature kCookieSameSiteConsidersRedirectChain{
 const base::Feature kSamePartyCookiesConsideredFirstParty{
     "SamePartyCookiesConsideredFirstParty", base::FEATURE_DISABLED_BY_DEFAULT};
 
+const base::Feature kPartitionedCookies{"PartitionedCookies",
+                                        base::FEATURE_DISABLED_BY_DEFAULT};
+
 }  // namespace features
 }  // namespace net
