@@ -116,8 +116,7 @@ bool AiaRequest::AddCompletedFetchToResults(Error error,
 
   // Handles PKCS#7 encoded certificates
   CertificateList certs = X509Certificate::CreateCertificateListFromBytes(
-      reinterpret_cast<const char*>(fetched_bytes.data()), fetched_bytes.size(),
-      X509Certificate::FORMAT_AUTO);
+      fetched_bytes, X509Certificate::FORMAT_AUTO);
   bool certs_ok = false;
   for (const auto& cert : certs) {
     auto parsed = ParsedCertificate::Create(
