@@ -3,6 +3,7 @@
 // found in the LICENSE file.
 
 #include "net/cert/internal/system_trust_store.h"
+#include "net/net_buildflags.h"
 
 #if defined(USE_NSS_CERTS)
 #include "net/cert/internal/system_trust_store_nss.h"
@@ -51,6 +52,9 @@
 #else
 #include "base/lazy_instance.h"
 #endif
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+#include "net/cert/internal/trust_store_chrome.h"
+#endif  // CHROME_ROOT_STORE_SUPPORTED
 
 namespace net {
 
@@ -72,6 +76,35 @@ class DummySystemTrustStore : public SystemTrustStore {
 
 }  // namespace
 
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+class SystemTrustStoreChrome : public SystemTrustStore {
+ public:
+  explicit SystemTrustStoreChrome(
+      std::unique_ptr<TrustStoreChrome> trust_store_chrome,
+      std::unique_ptr<TrustStore> trust_store_system)
+      : trust_store_chrome_(std::move(trust_store_chrome)),
+        trust_store_system_(std::move(trust_store_system)) {
+    trust_store_collection_.AddTrustStore(trust_store_chrome_.get());
+    trust_store_collection_.AddTrustStore(trust_store_system_.get());
+  }
+
+  TrustStore* GetTrustStore() override { return &trust_store_collection_; }
+
+  bool UsesSystemTrustStore() const override { return true; }
+
+  // IsKnownRoot returns true if the given trust anchor is a standard one (as
+  // opposed to a user-installed root)
+  bool IsKnownRoot(const ParsedCertificate* trust_anchor) const override {
+    return trust_store_chrome_->Contains(trust_anchor);
+  }
+
+ private:
+  std::unique_ptr<TrustStoreChrome> trust_store_chrome_;
+  std::unique_ptr<TrustStore> trust_store_system_;
+  TrustStoreCollection trust_store_collection_;
+};
+#endif  // CHROME_ROOT_STORE_SUPPORTED
+
 #if defined(USE_NSS_CERTS)
 namespace {
 
@@ -117,6 +150,23 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
       std::make_unique<TrustStoreNSS>(trustSSL));
 }
 
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<SystemTrustStoreChrome>(
+      std::make_unique<TrustStoreChrome>(),
+      std::make_unique<TrustStoreNSS>(
+          trustSSL, TrustStoreNSS::IgnoreSystemTrustSettings()));
+}
+
+#else
+
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<DummySystemTrustStore>();
+}
+
+#endif  // CHROME_ROOT_STORE_SUPPORTED
+
 std::unique_ptr<SystemTrustStore>
 CreateSslSystemTrustStoreNSSWithUserSlotRestriction(
     crypto::ScopedPK11Slot user_slot) {
@@ -202,6 +252,10 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<SystemTrustStoreMac>();
 }
 
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<DummySystemTrustStore>();
+}
+
 void InitializeTrustStoreMacCache() {
   base::ThreadPool::PostTask(
       FROM_HERE,
@@ -270,6 +324,10 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<SystemTrustStoreFuchsia>();
 }
 
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<DummySystemTrustStore>();
+}
+
 #elif defined(OS_LINUX) || defined(OS_ANDROID)
 
 namespace {
@@ -305,7 +363,12 @@ constexpr char kStaticCertDirsEnv[] = "SSL_CERT_DIR";
 
 class StaticUnixSystemCerts {
  public:
-  StaticUnixSystemCerts() {
+  StaticUnixSystemCerts() : system_trust_store_(Create()) {}
+
+  TrustStoreInMemory* system_trust_store() { return system_trust_store_.get(); }
+
+  static std::unique_ptr<TrustStoreInMemory> Create() {
+    auto ptr = std::make_unique<TrustStoreInMemory>();
     auto env = base::Environment::Create();
     std::string env_value;
 
@@ -320,7 +383,7 @@ class StaticUnixSystemCerts {
       std::string file;
       if (!base::ReadFileToString(base::FilePath(filename), &file))
         continue;
-      if (AddCertificatesFromBytes(file.data(), file.size())) {
+      if (AddCertificatesFromBytes(file.data(), file.size(), ptr.get())) {
         cert_file_ok = true;
         break;
       }
@@ -342,7 +405,7 @@ class StaticUnixSystemCerts {
         if (!base::ReadFileToString(filename, &file)) {
           continue;
         }
-        if (AddCertificatesFromBytes(file.data(), file.size())) {
+        if (AddCertificatesFromBytes(file.data(), file.size(), ptr.get())) {
           cert_dir_ok = true;
         }
       }
@@ -354,12 +417,14 @@ class StaticUnixSystemCerts {
       LOG(ERROR) << "No CA certificates were found. Try using environment "
                     "variable SSL_CERT_FILE or SSL_CERT_DIR";
     }
+
+    return ptr;
   }
 
-  TrustStoreInMemory* system_trust_store() { return &system_trust_store_; }
-
  private:
-  bool AddCertificatesFromBytes(const char* data, size_t length) {
+  static bool AddCertificatesFromBytes(const char* data,
+                                       size_t length,
+                                       TrustStoreInMemory* store) {
     auto certs = X509Certificate::CreateCertificateListFromBytes(
         {reinterpret_cast<const uint8_t*>(data), length},
         X509Certificate::FORMAT_AUTO);
@@ -370,8 +435,8 @@ class StaticUnixSystemCerts {
           bssl::UpRef(cert->cert_buffer()),
           x509_util::DefaultParseCertificateOptions(), &errors);
       if (parsed) {
-        if (!system_trust_store_.Contains(parsed.get())) {
-          system_trust_store_.AddTrustAnchor(parsed);
+        if (!store->Contains(parsed.get())) {
+          store->AddTrustAnchor(parsed);
         }
         certs_ok = true;
       } else {
@@ -381,7 +446,7 @@ class StaticUnixSystemCerts {
     return certs_ok;
   }
 
-  TrustStoreInMemory system_trust_store_;
+  std::unique_ptr<TrustStoreInMemory> system_trust_store_;
 };
 
 base::LazyInstance<StaticUnixSystemCerts>::Leaky g_root_certs_static_unix =
@@ -409,12 +474,31 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<SystemTrustStoreStaticUnix>();
 }
 
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<SystemTrustStoreChrome>(
+      std::make_unique<TrustStoreChrome>(), StaticUnixSystemCerts::Create());
+}
+
+#else
+
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<DummySystemTrustStore>();
+}
+
+#endif  // CHROME_ROOT_STORE_SUPPORTED
+
 #else
 
 std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<DummySystemTrustStore>();
 }
 
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+  return std::make_unique<DummySystemTrustStore>();
+}
+
 #endif
 
 std::unique_ptr<SystemTrustStore> CreateEmptySystemTrustStore() {
