@@ -221,6 +221,7 @@ std::string CookieInclusionStatus::GetDebugString() const {
            {EXCLUDE_INVALID_DOMAIN, "EXCLUDE_INVALID_DOMAIN"},
            {EXCLUDE_INVALID_PREFIX, "EXCLUDE_INVALID_PREFIX"},
            {EXCLUDE_INVALID_SAMEPARTY, "EXCLUDE_INVALID_SAMEPARTY"},
+           {EXCLUDE_INVALID_PARTITIONED, "EXCLUDE_INVALID_PARTITIONED"},
        }) {
     if (HasExclusionReason(reason.first))
       base::StrAppend(&out, {reason.second, ", "});
@@ -255,8 +256,6 @@ std::string CookieInclusionStatus::GetDebugString() const {
             "WARN_SAMEPARTY_EXCLUSION_OVERRULED_SAMESITE"},
            {WARN_SAMEPARTY_INCLUSION_OVERRULED_SAMESITE,
             "WARN_SAMEPARTY_INCLUSION_OVERRULED_SAMESITE"},
-           {WARN_SAMESITE_LAX_EXCLUDED_AFTER_BUGFIX_1166211,
-            "WARN_SAMESITE_LAX_EXCLUDED_AFTER_BUGFIX_1166211"},
            {WARN_SAMESITE_NONE_REQUIRED, "WARN_SAMESITE_NONE_REQUIRED"},
            {WARN_SAMESITE_NONE_INCLUDED_BY_SAMEPARTY_TOP_RESOURCE,
             "WARN_SAMESITE_NONE_INCLUDED_BY_SAMEPARTY_TOP_RESOURCE"},
