@@ -253,7 +253,8 @@ int HostResolver::SquashErrorCode(int error) {
   // ERR_NOT_IMPLEMENTED.
   // TODO(crbug.com/1043281): Consider squashing ERR_INTERNET_DISCONNECTED.
   if (error == OK || error == ERR_IO_PENDING || error == ERR_NOT_IMPLEMENTED ||
-      error == ERR_INTERNET_DISCONNECTED || error == ERR_NAME_NOT_RESOLVED) {
+      error == ERR_INTERNET_DISCONNECTED || error == ERR_NAME_NOT_RESOLVED ||
+      error == ERR_DNS_NAME_HTTPS_ONLY) {
     return error;
   } else {
     return ERR_NAME_NOT_RESOLVED;
