@@ -83,106 +83,103 @@ const uint32_t kSpdyMaxHeaderListSize = 256 * 1024;
 // Specifies the maximum concurrent streams server could send (via push).
 const uint32_t kSpdyMaxConcurrentPushedStreams = 1000;
 
-// This class holds session objects used by HttpNetworkTransaction objects.
-class NET_EXPORT HttpNetworkSession {
- public:
   // Self-contained structure with all the simple configuration options
   // supported by the HttpNetworkSession.
-  struct NET_EXPORT Params {
-    Params();
-    Params(const Params& other);
-    ~Params();
+struct NET_EXPORT HttpNetworkSessionParams {
+  HttpNetworkSessionParams();
+  HttpNetworkSessionParams(const HttpNetworkSessionParams& other);
+  ~HttpNetworkSessionParams();
 
-    bool enable_server_push_cancellation;
-    HostMappingRules host_mapping_rules;
-    bool ignore_certificate_errors;
-    uint16_t testing_fixed_http_port;
-    uint16_t testing_fixed_https_port;
-    bool enable_user_alternate_protocol_ports;
+  bool enable_server_push_cancellation;
+  HostMappingRules host_mapping_rules;
+  bool ignore_certificate_errors;
+  uint16_t testing_fixed_http_port;
+  uint16_t testing_fixed_https_port;
+  bool enable_user_alternate_protocol_ports;
 
-    // Use SPDY ping frames to test for connection health after idle.
-    bool enable_spdy_ping_based_connection_checking;
-    bool enable_http2;
-    size_t spdy_session_max_recv_window_size;
-    // Maximum number of capped frames that can be queued at any time.
-    int spdy_session_max_queued_capped_frames;
-    // HTTP/2 connection settings.
-    // Unknown settings will still be sent to the server.
-    // Might contain unknown setting identifiers from a predefined set that
-    // servers are supposed to ignore, see
-    // https://tools.ietf.org/html/draft-bishop-httpbis-grease-00.
-    // The same setting will be sent on every connection to prevent the retry
-    // logic from hiding broken servers.
-    spdy::SettingsMap http2_settings;
-    // If set, an HTTP/2 frame with a reserved frame type will be sent after
-    // every HTTP/2 SETTINGS frame and before every HTTP/2 DATA frame.
-    // https://tools.ietf.org/html/draft-bishop-httpbis-grease-00.
-    // The same frame will be sent out on all connections to prevent the retry
-    // logic from hiding broken servers.
-    absl::optional<SpdySessionPool::GreasedHttp2Frame> greased_http2_frame;
-    // If set, the HEADERS frame carrying a request without body will not have
-    // the END_STREAM flag set.  The stream will be closed by a subsequent empty
-    // DATA frame with END_STREAM.  Does not affect bidirectional or proxy
-    // streams.
-    // If unset, the HEADERS frame will have the END_STREAM flag set on.
-    // This is useful in conjuction with |greased_http2_frame| so that a frame
-    // of reserved type can be sent out even on requests without a body.
-    bool http2_end_stream_with_data_frame;
-    // Source of time for SPDY connections.
-    SpdySessionPool::TimeFunc time_func;
-    // Whether to enable HTTP/2 Alt-Svc entries.
-    bool enable_http2_alternative_service;
-    // Whether to enable Websocket over HTTP/2.
-    bool enable_websocket_over_http2;
+  // Use SPDY ping frames to test for connection health after idle.
+  bool enable_spdy_ping_based_connection_checking;
+  bool enable_http2;
+  size_t spdy_session_max_recv_window_size;
+  // Maximum number of capped frames that can be queued at any time.
+  int spdy_session_max_queued_capped_frames;
+  // HTTP/2 connection settings.
+  // Unknown settings will still be sent to the server.
+  // Might contain unknown setting identifiers from a predefined set that
+  // servers are supposed to ignore, see
+  // https://tools.ietf.org/html/draft-bishop-httpbis-grease-00.
+  // The same setting will be sent on every connection to prevent the retry
+  // logic from hiding broken servers.
+  spdy::SettingsMap http2_settings;
+  // If set, an HTTP/2 frame with a reserved frame type will be sent after
+  // every HTTP/2 SETTINGS frame and before every HTTP/2 DATA frame.
+  // https://tools.ietf.org/html/draft-bishop-httpbis-grease-00.
+  // The same frame will be sent out on all connections to prevent the retry
+  // logic from hiding broken servers.
+  absl::optional<SpdySessionPool::GreasedHttp2Frame> greased_http2_frame;
+  // If set, the HEADERS frame carrying a request without body will not have
+  // the END_STREAM flag set.  The stream will be closed by a subsequent empty
+  // DATA frame with END_STREAM.  Does not affect bidirectional or proxy
+  // streams.
+  // If unset, the HEADERS frame will have the END_STREAM flag set on.
+  // This is useful in conjunction with |greased_http2_frame| so that a frame
+  // of reserved type can be sent out even on requests without a body.
+  bool http2_end_stream_with_data_frame;
+  // Source of time for SPDY connections.
+  SpdySessionPool::TimeFunc time_func;
+  // Whether to enable HTTP/2 Alt-Svc entries.
+  bool enable_http2_alternative_service;
+  // Whether to enable Websocket over HTTP/2.
+  bool enable_websocket_over_http2;
 
-    // Enables 0-RTT support.
-    bool enable_early_data;
+  // Enables 0-RTT support.
+  bool enable_early_data;
 
-    // Enables QUIC support.
-    bool enable_quic;
+  // Enables QUIC support.
+  bool enable_quic;
 
-    // If true, HTTPS URLs can be sent to QUIC proxies.
-    bool enable_quic_proxies_for_https_urls;
+  // If true, HTTPS URLs can be sent to QUIC proxies.
+  bool enable_quic_proxies_for_https_urls;
 
-    // If non-empty, QUIC will only be spoken to hosts in this list.
-    base::flat_set<std::string> quic_host_allowlist;
+  // If non-empty, QUIC will only be spoken to hosts in this list.
+  base::flat_set<std::string> quic_host_allowlist;
 
-    // If true, idle sockets won't be closed when memory pressure happens.
-    bool disable_idle_sockets_close_on_memory_pressure;
+  // If true, idle sockets won't be closed when memory pressure happens.
+  bool disable_idle_sockets_close_on_memory_pressure;
 
-    bool key_auth_cache_server_entries_by_network_isolation_key;
+  bool key_auth_cache_server_entries_by_network_isolation_key;
 
-    // If true, enable sending PRIORITY_UPDATE frames until SETTINGS frame
-    // arrives.  After SETTINGS frame arrives, do not send PRIORITY_UPDATE
-    // frames any longer if SETTINGS_DEPRECATE_HTTP2_PRIORITIES is missing or
-    // has zero 0, but continue and also stop sending HTTP/2-style priority
-    // information in HEADERS frames and PRIORITY frames if it has value 1.
-    bool enable_priority_update;
-  };
+  // If true, enable sending PRIORITY_UPDATE frames until SETTINGS frame
+  // arrives.  After SETTINGS frame arrives, do not send PRIORITY_UPDATE
+  // frames any longer if SETTINGS_DEPRECATE_HTTP2_PRIORITIES is missing or
+  // has zero 0, but continue and also stop sending HTTP/2-style priority
+  // information in HEADERS frames and PRIORITY frames if it has value 1.
+  bool enable_priority_update;
+};
 
   // Structure with pointers to the dependencies of the HttpNetworkSession.
   // These objects must all outlive the HttpNetworkSession.
-  struct NET_EXPORT Context {
-    Context();
-    Context(const Context& other);
-    ~Context();
+struct NET_EXPORT HttpNetworkSessionContext {
+  HttpNetworkSessionContext();
+  HttpNetworkSessionContext(const HttpNetworkSessionContext& other);
+  ~HttpNetworkSessionContext();
 
-    ClientSocketFactory* client_socket_factory;
-    HostResolver* host_resolver;
-    CertVerifier* cert_verifier;
-    TransportSecurityState* transport_security_state;
-    CTPolicyEnforcer* ct_policy_enforcer;
-    SCTAuditingDelegate* sct_auditing_delegate;
-    ProxyResolutionService* proxy_resolution_service;
-    ProxyDelegate* proxy_delegate;
-    const HttpUserAgentSettings* http_user_agent_settings;
-    SSLConfigService* ssl_config_service;
-    HttpAuthHandlerFactory* http_auth_handler_factory;
-    HttpServerProperties* http_server_properties;
-    NetLog* net_log;
-    SocketPerformanceWatcherFactory* socket_performance_watcher_factory;
-    NetworkQualityEstimator* network_quality_estimator;
-    QuicContext* quic_context;
+  ClientSocketFactory* client_socket_factory;
+  HostResolver* host_resolver;
+  CertVerifier* cert_verifier;
+  TransportSecurityState* transport_security_state;
+  CTPolicyEnforcer* ct_policy_enforcer;
+  SCTAuditingDelegate* sct_auditing_delegate;
+  ProxyResolutionService* proxy_resolution_service;
+  ProxyDelegate* proxy_delegate;
+  const HttpUserAgentSettings* http_user_agent_settings;
+  SSLConfigService* ssl_config_service;
+  HttpAuthHandlerFactory* http_auth_handler_factory;
+  HttpServerProperties* http_server_properties;
+  NetLog* net_log;
+  SocketPerformanceWatcherFactory* socket_performance_watcher_factory;
+  NetworkQualityEstimator* network_quality_estimator;
+  QuicContext* quic_context;
 #if BUILDFLAG(ENABLE_REPORTING)
     ReportingService* reporting_service;
     NetworkErrorLoggingService* network_error_logging_service;
@@ -190,15 +187,19 @@ class NET_EXPORT HttpNetworkSession {
 
     // Optional factory to use for creating QuicCryptoClientStreams.
     QuicCryptoClientStreamFactory* quic_crypto_client_stream_factory;
-  };
+};
 
+// This class holds session objects used by HttpNetworkTransaction objects.
+class NET_EXPORT HttpNetworkSession {
+ public:
   enum SocketPoolType {
     NORMAL_SOCKET_POOL,
     WEBSOCKET_SOCKET_POOL,
     NUM_SOCKET_POOL_TYPES
   };
 
-  HttpNetworkSession(const Params& params, const Context& context);
+  HttpNetworkSession(const HttpNetworkSessionParams& params,
+                     const HttpNetworkSessionContext& context);
   ~HttpNetworkSession();
 
   HttpAuthCache* http_auth_cache() { return &http_auth_cache_; }
@@ -259,9 +260,9 @@ class NET_EXPORT HttpNetworkSession {
   void CloseIdleConnections(const char* net_log_reason_utf8);
 
   // Returns the original Params used to construct this session.
-  const Params& params() const { return params_; }
+  const HttpNetworkSessionParams& params() const { return params_; }
   // Returns the original Context used to construct this session.
-  const Context& context() const { return context_; }
+  const HttpNetworkSessionContext& context() const { return context_; }
 
   void SetServerPushDelegate(std::unique_ptr<ServerPushDelegate> push_delegate);
 
@@ -335,8 +336,8 @@ class NET_EXPORT HttpNetworkSession {
   NextProtoVector next_protos_;
   SSLConfig::ApplicationSettings application_settings_;
 
-  Params params_;
-  Context context_;
+  HttpNetworkSessionParams params_;
+  HttpNetworkSessionContext context_;
 
   std::unique_ptr<base::MemoryPressureListener> memory_pressure_listener_;
 
