@@ -4,6 +4,7 @@
 
 #include "net/http/http_network_session_peer.h"
 
+#include "net/http/http_network_session.h"
 #include "net/proxy_resolution/proxy_resolution_service.h"
 #include "net/socket/client_socket_pool_manager.h"
 #include "net/socket/transport_client_socket_pool.h"
@@ -25,7 +26,7 @@ void HttpNetworkSessionPeer::SetHttpStreamFactory(
   session_->http_stream_factory_.swap(http_stream_factory);
 }
 
-HttpNetworkSession::Params* HttpNetworkSessionPeer::params() {
+HttpNetworkSessionParams* HttpNetworkSessionPeer::params() {
   return &(session_->params_);
 }
 
