@@ -11,7 +11,9 @@
 #include <string>
 #include <vector>
 
+#include "base/command_line.h"
 #include "base/export_template.h"
+#include "base/no_destructor.h"
 #include "net/third_party/quiche/src/common/platform/api/quiche_flags.h"
 #include "net/third_party/quiche/src/quic/platform/api/quic_export.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
@@ -21,12 +23,6 @@
 #include "net/third_party/quiche/src/quic/core/quic_protocol_flags_list.h"
 #undef QUIC_PROTOCOL_FLAG
 
-namespace base {
-class CommandLine;
-template <typename T>
-class NoDestructor;
-}  // namespace base
-
 // Sets the flag named |flag_name| to the value of |value| after converting
 // it from a string to the appropriate type. If |value| is invalid or out of
 // range, the flag will be unchanged.
@@ -72,6 +68,9 @@ template <>
 QUIC_EXPORT_PRIVATE bool TypedQuicFlagHelper<bool>::SetFlag(
     const std::string&) const;
 template <>
+QUIC_EXPORT_PRIVATE bool TypedQuicFlagHelper<uint16_t>::SetFlag(
+    const std::string&) const;
+template <>
 QUIC_EXPORT_PRIVATE bool TypedQuicFlagHelper<int32_t>::SetFlag(
     const std::string&) const;
 template <>
@@ -81,6 +80,8 @@ QUIC_EXPORT_PRIVATE bool TypedQuicFlagHelper<std::string>::SetFlag(
 // TypedQuicFlagHelper instantiations are in .cc file.
 extern template class EXPORT_TEMPLATE_DECLARE(QUIC_EXPORT_PRIVATE)
     TypedQuicFlagHelper<bool>;
+extern template class EXPORT_TEMPLATE_DECLARE(QUIC_EXPORT_PRIVATE)
+    TypedQuicFlagHelper<uint16_t>;
 extern template class EXPORT_TEMPLATE_DECLARE(QUIC_EXPORT_PRIVATE)
     TypedQuicFlagHelper<int32_t>;
 extern template class EXPORT_TEMPLATE_DECLARE(QUIC_EXPORT_PRIVATE)
