@@ -313,6 +313,11 @@ class TestReportingService : public ReportingService {
 
   ~TestReportingService() override;
 
+  void SetDocumentReportingEndpoints(
+      const url::Origin& origin,
+      const net::NetworkIsolationKey& network_isolation_key,
+      const base::flat_map<std::string, std::string>& endpoints) override {}
+
   void QueueReport(const GURL& url,
                    const NetworkIsolationKey& network_isolation_key,
                    const std::string& user_agent,
@@ -325,11 +330,6 @@ class TestReportingService : public ReportingService {
                              const NetworkIsolationKey& network_isolation_key,
                              const std::string& header_value) override;
 
-  void ProcessReportingEndpointsHeader(
-      const url::Origin& origin,
-      const NetworkIsolationKey& network_isolation_key,
-      const std::string& header_value) override;
-
   void RemoveBrowsingData(
       uint64_t data_type_mask,
       const base::RepeatingCallback<bool(const GURL&)>& origin_filter) override;
