@@ -17,6 +17,7 @@
 #include "net/dns/public/secure_dns_policy.h"
 #include "net/http/http_network_session.h"
 #include "net/socket/client_socket_pool.h"
+#include "url/scheme_host_port.h"
 
 namespace base {
 class Value;
@@ -28,7 +29,6 @@ class ProcessMemoryDump;
 namespace net {
 
 class ClientSocketHandle;
-class HostPortPair;
 class NetLogWithSource;
 class NetworkIsolationKey;
 class ProxyInfo;
@@ -42,11 +42,6 @@ enum DefaultMaxValues { kDefaultMaxSocketsPerProxyServer = 32 };
 
 class NET_EXPORT_PRIVATE ClientSocketPoolManager {
  public:
-  enum SocketGroupType {
-    SSL_GROUP,     // For all TLS sockets.
-    NORMAL_GROUP,  // For normal HTTP sockets.
-  };
-
   ClientSocketPoolManager();
   virtual ~ClientSocketPoolManager();
 
@@ -101,8 +96,7 @@ class NET_EXPORT_PRIVATE ClientSocketPoolManager {
 // resolved.  If |resolution_callback| does not return OK, then the
 // connection will be aborted with that value.
 int InitSocketHandleForHttpRequest(
-    ClientSocketPoolManager::SocketGroupType group_type,
-    const HostPortPair& endpoint,
+    url::SchemeHostPort endpoint,
     int request_load_flags,
     RequestPriority request_priority,
     HttpNetworkSession* session,
@@ -110,7 +104,7 @@ int InitSocketHandleForHttpRequest(
     const SSLConfig& ssl_config_for_origin,
     const SSLConfig& ssl_config_for_proxy,
     PrivacyMode privacy_mode,
-    const NetworkIsolationKey& network_isolation_key,
+    NetworkIsolationKey network_isolation_key,
     SecureDnsPolicy secure_dns_policy,
     const SocketTag& socket_tag,
     const NetLogWithSource& net_log,
@@ -128,8 +122,7 @@ int InitSocketHandleForHttpRequest(
 // connection will be aborted with that value.
 // This function uses WEBSOCKET_SOCKET_POOL socket pools.
 int InitSocketHandleForWebSocketRequest(
-    ClientSocketPoolManager::SocketGroupType group_type,
-    const HostPortPair& endpoint,
+    url::SchemeHostPort endpoint,
     int request_load_flags,
     RequestPriority request_priority,
     HttpNetworkSession* session,
@@ -137,7 +130,7 @@ int InitSocketHandleForWebSocketRequest(
     const SSLConfig& ssl_config_for_origin,
     const SSLConfig& ssl_config_for_proxy,
     PrivacyMode privacy_mode,
-    const NetworkIsolationKey& network_isolation_key,
+    NetworkIsolationKey network_isolation_key,
     const NetLogWithSource& net_log,
     ClientSocketHandle* socket_handle,
     CompletionOnceCallback callback,
@@ -152,27 +145,25 @@ NET_EXPORT int InitSocketHandleForRawConnect2(
     const SSLConfig& ssl_config_for_origin,
     const SSLConfig& ssl_config_for_proxy,
     PrivacyMode privacy_mode,
-    const NetworkIsolationKey& network_isolation_key,
+    NetworkIsolationKey network_isolation_key,
     const NetLogWithSource& net_log,
     ClientSocketHandle* socket_handle,
     CompletionOnceCallback callback);
 
 // Similar to InitSocketHandleForHttpRequest except that it initiates the
 // desired number of preconnect streams from the relevant socket pool.
-int PreconnectSocketsForHttpRequest(
-    ClientSocketPoolManager::SocketGroupType group_type,
-    const HostPortPair& endpoint,
-    int request_load_flags,
-    RequestPriority request_priority,
-    HttpNetworkSession* session,
-    const ProxyInfo& proxy_info,
-    const SSLConfig& ssl_config_for_origin,
-    const SSLConfig& ssl_config_for_proxy,
-    PrivacyMode privacy_mode,
-    const NetworkIsolationKey& network_isolation_key,
-    SecureDnsPolicy secure_dns_policy,
-    const NetLogWithSource& net_log,
-    int num_preconnect_streams);
+int PreconnectSocketsForHttpRequest(url::SchemeHostPort endpoint,
+                                    int request_load_flags,
+                                    RequestPriority request_priority,
+                                    HttpNetworkSession* session,
+                                    const ProxyInfo& proxy_info,
+                                    const SSLConfig& ssl_config_for_origin,
+                                    const SSLConfig& ssl_config_for_proxy,
+                                    PrivacyMode privacy_mode,
+                                    NetworkIsolationKey network_isolation_key,
+                                    SecureDnsPolicy secure_dns_policy,
+                                    const NetLogWithSource& net_log,
+                                    int num_preconnect_streams);
 
 }  // namespace net
 
