@@ -12,10 +12,10 @@
 #include <string>
 
 #include "base/macros.h"
-#include "base/optional.h"
 #include "base/strings/string_piece.h"
 #include "base/strings/string_util.h"
 #include "net/ssl/ssl_info.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
 #include "url/gurl.h"
 
 namespace net {
@@ -65,7 +65,7 @@ struct HttpRequest {
   HeaderMap headers;
   std::string content;
   bool has_content;
-  base::Optional<SSLInfo> ssl_info;
+  absl::optional<SSLInfo> ssl_info;
 };
 
 // Parses the input data and produces a valid HttpRequest object. If there is
