@@ -116,7 +116,7 @@ bool RemoteTestServer::StartInBackground() {
   if (!GenerateArguments(&arguments_dict))
     return false;
 
-  arguments_dict.Set("on-remote-server", std::make_unique<base::Value>());
+  arguments_dict.SetKey("on-remote-server", base::Value());
 
   // Append the 'server-type' argument which is used by spawner server to
   // pass right server type to Python test server.
